@@ -11,7 +11,7 @@
 use strict;
 use warnings;
 
-use OP;
+use OP qw| :all |;
 use OP::Constants qw| dbHost dbPass dbPort dbUser |;
 
 create "OP::ForeignRow" => {
