@@ -53,7 +53,7 @@ This file is part of L<OP>.
 use strict;
 use warnings;
 
-use OP;
+use OP qw| :all |;
 
 use OP::Enum::DBIType;
 use OP::Enum::State;
